@@ -91,14 +91,19 @@ function RandomizerPowerup.ChangeSuit()
     for _, suit in ipairs(suits) do
         if suit.model == model_updater.sModelAlias then break end
         if RandomizerPowerup.GetItemAmount(suit.item) > 0 then
-            Game.LogWarn(0, "Updating suit to " .. suit.model)
-            model_updater.sModelAlias = suit.model
-            model_updater:ForceUpdate()
+            Game.AddPSF(0.2, RandomizerPowerup.Delayed_ChangeSuit, "s", suit.model)
             break
         end
     end
 end
 
+function RandomizerPowerup.Delayed_ChangeSuit(model)
+    -- some race condition causes it to crash if you don't wait a little while to update
+    local model_updater = Game.GetPlayer().MODELUPDATER
+    Game.LogWarn(0, "Updating suit to " .. model)
+    model_updater.sModelAlias = model
+end
+
 function RandomizerPowerup.IncreaseEnergy(resource)
     if resource == nil then return end
     local item_id = resource.item_id
@@ -144,15 +149,26 @@ function RandomizerPowerBomb.OnPickedUp(actor, progression)
     end
 end
 
+function RandomizerPowerup.ToggleInputsOnPickedUp(actor, progression, item, SFs)
+    SFs = SFs or {}
+    local has_item_already = RandomizerPowerup.GetItemAmount(item)
+    RandomizerPowerup.OnPickedUp(actor, progression)
+    if not has_item_already then
+        RandomizerPowerup.DisableInput()
+        for _, SF in ipairs(SFs) do
+            Game.AddSF(table.unpack(SF))
+        end
+    end
+end
+
 RandomizerPhantomCloak = {}
 setmetatable(RandomizerPhantomCloak, {__index = RandomizerPowerup})
 function RandomizerPhantomCloak.OnPickedUp(actor, progression)
-    local has_cloak_already = RandomizerPowerup.GetItemAmount("ITEM_OPTIC_CAMOUFLAGE") > 0
-    RandomizerPowerup.OnPickedUp(actor, progression)
-    if not has_cloak_already then
-        RandomizerPowerup.DisableInput()
-        Game.AddSF(0.101, RandomizerPhantomCloak.Deactivate, "")
-    end
+    RandomizerPowerup.ToggleInputsOnPickedUp(
+        actor, progression, "ITEM_OPTIC_CAMOUFLAGE", {
+            {0.101, RandomizerPhantomCloak.Deactivate, ""}
+        }
+    )
 end
 
 function RandomizerPhantomCloak.Deactivate()
@@ -163,9 +179,15 @@ end
 RandomizerSpeedBooster = {}
 setmetatable(RandomizerSpeedBooster, {__index = RandomizerPowerup})
 function RandomizerSpeedBooster.OnPickedUp(actor, progression)
-    local has_speed_already = RandomizerPowerup.GetItemAmount("ITEM_SPEED_BOOSTER") > 0
-    RandomizerPowerup.OnPickedUp(actor, progression)
-    if not has_speed_already then
-        RandomizerPowerup.DisableInput()
-    end
+    RandomizerPowerup.ToggleInputsOnPickedUp(
+        actor, progression, "ITEM_SPEED_BOOSTER"
+    )
+end
+
+RandomizerStormMissile = {}
+setmetatable(RandomizerStormMissile, {__index = RandomizerPowerup})
+function RandomizerStormMissile.OnPickedUp(actor, progression)
+    RandomizerPowerup.ToggleInputsOnPickedUp(
+        actor, progression, "ITEM_MULTILOCKON"
+    )
 end
